/*----------------------------------------------------------------------
  File    : dialog.h
  Contents: simplified dialog definition for Athena widgets
            (action functions, alert/about dialog, property sheets)
  History : 14.05.1998 file created as psheet.h
            03.06.1998 minor improvements
            12.01.2000 action functions and alert/about dialog added
----------------------------------------------------------------------*/
#ifndef __DIALOG__
#define __DIALOG__
#include <X11/Intrinsic.h>

/*----------------------------------------------------------------------
  Preprocessor Definitions
----------------------------------------------------------------------*/
#define PS_LABEL    0           /* label */
#define PS_COMMAND  1           /* command button */
#define PS_TEXT     2           /* non-editable text field */
#define PS_EDIT     3           /* editable text field */
#define PS_TOGGLE   4           /* toggle button (checkbox) */
#define PS_RADIO    5           /* radio button */
#define PS_MENU     6           /* menu */

/*----------------------------------------------------------------------
  Type Definitions
----------------------------------------------------------------------*/
typedef struct {                /* --- property sheet item --- */
  Widget widget;                /* item widget */
  int    type;                  /* item type (e.g. PS_COMMAND) */
} PSITEM;                       /* (property sheet item) */

typedef struct {                /* --- property sheet --- */
  Widget parent;                /* parent widget */
  Widget shell;                 /* shell widget */
  Widget form;                  /* form widget */
  Widget ok, ca;                /* ok and cancel button */
  Widget currline;              /* current  line */
  Widget prevline;              /* previous line */
  Widget previtem;              /* previous item */
  int    itemvsz;               /* size of items vector */
  int    itemcnt;               /* number of items */
  PSITEM *items;                /* property sheet items */
} PSHEET;                       /* (property sheet) */

/*----------------------------------------------------------------------
  Dialog Box Action Functions
----------------------------------------------------------------------*/
extern void db_focus (Widget w, XEvent *e, String *s, Cardinal *c);
extern void db_next  (Widget w, XEvent *e, String *s, Cardinal *c);
extern void db_close (Widget w, XEvent *e, String *s, Cardinal *c);

/*----------------------------------------------------------------------
  Alert/About Box Functions
----------------------------------------------------------------------*/
extern int  db_alert (Widget parent, XtCallbackProc callback,
                      const char *msg);
extern int  db_about (Widget parent, XtCallbackProc callback);

/*----------------------------------------------------------------------
  Property Sheet Functions
----------------------------------------------------------------------*/
extern PSHEET*     ps_create  (const char *name, Widget parent,
                               int cabutton);
extern void        ps_delete  (PSHEET *psh);
extern int         ps_addline (PSHEET *psh, const char *name);
extern int         ps_additem (PSHEET *psh, const char *name,
                               int type, int width);
extern int         ps_addcb   (PSHEET *psh, const char *name,
                               XtCallbackProc callback, XtPointer data);
extern int         ps_menuadd (PSHEET *psh, const char *name,
                                            const char *text);
extern int         ps_setval  (PSHEET *psh, const char *name,
                                            const char *text);
extern const char* ps_getval  (PSHEET *psh, const char *name);
extern int         ps_handle  (PSHEET *psh, XtCallbackProc callback);

#endif

